@@ -272,6 +272,9 @@ INVALIDPARAMETERVALUE_INVALIDINSTANCESTATE = 'InvalidParameterValue.InvalidInsta
 # 无效的IPv6地址。
 INVALIDPARAMETERVALUE_INVALIDIPV6 = 'InvalidParameterValue.InvalidIpv6'
 
+# 旧的带宽值无效。
+INVALIDPARAMETERVALUE_INVALIDOLDBANDWIDTH = 'InvalidParameterValue.InvalidOldBandwidth'
+
 # 该Tag不合法。
 INVALIDPARAMETERVALUE_INVALIDTAG = 'InvalidParameterValue.InvalidTag'
 
@@ -338,6 +341,9 @@ INVALIDPARAMETERVALUE_NETDETECTSAMEIP = 'InvalidParameterValue.NetDetectSameIp'
 # 网络接口ID不正确。
 INVALIDPARAMETERVALUE_NETWORKINTERFACEIDMALFORMED = 'InvalidParameterValue.NetworkInterfaceIdMalformed'
 
+# 网卡所绑定实例不支持绑定弹性公网IPv6
+INVALIDPARAMETERVALUE_NETWORKINTERFACEINSTANCENOTSUPPORT = 'InvalidParameterValue.NetworkInterfaceInstanceNotSupport'
+
 # 未找到网络接口ID，或私有IP地址未在网络接口配置。
 INVALIDPARAMETERVALUE_NETWORKINTERFACENOTFOUND = 'InvalidParameterValue.NetworkInterfaceNotFound'
 
@@ -458,6 +464,9 @@ INVALIDPARAMETERVALUE_TRAFFICPACKAGENOTFOUND = 'InvalidParameterValue.TrafficPac
 # 指定的流量包不支持此操作
 INVALIDPARAMETERVALUE_TRAFFICPACKAGENOTSUPPORTED = 'InvalidParameterValue.TrafficPackageNotSupported'
 
+# 指定的流量包资源ID不合法
+INVALIDPARAMETERVALUE_TRAFFICPACKAGERESOURCEIDMALFORMED = 'InvalidParameterValue.TrafficPackageResourceIdMalformed'
+
 # 该可用区不可用。
 INVALIDPARAMETERVALUE_UNAVAILABLEZONE = 'InvalidParameterValue.UnavailableZone'
 
@@ -599,6 +608,9 @@ LIMITEXCEEDED_PUBLICIPADDRESSPERNATGATEWAYLIMITEXCEEDED = 'LimitExceeded.PublicI
 # 安全组规则数量超过上限。
 LIMITEXCEEDED_SECURITYGROUPPOLICYSET = 'LimitExceeded.SecurityGroupPolicySet'
 
+# SSL-VPN客户端个数大于SSL-VPN-SERVER客户端地址池能够分配的个数。
+LIMITEXCEEDED_SSLVPNCLIENTLIMITEXCEEDED = 'LimitExceeded.SslVpnClientLimitExceeded'
+
 # 子网分配子网段数量达到上限。
 LIMITEXCEEDED_SUBNETCIDRBLOCK = 'LimitExceeded.SubnetCidrBlock'
 
@@ -632,6 +644,9 @@ LIMITEXCEEDED_VPCPEERTOTALLIMITEXCEEDED = 'LimitExceeded.VpcPeerTotalLimitExceed
 # 缺少参数错误。
 MISSINGPARAMETER = 'MissingParameter'
 
+# 缺少多个参数错误
+MISSINGPARAMETER_MULTIMISSINGPARAMETER = 'MissingParameter.MultiMissingParameter'
+
 # 指定公网IP处于隔离状态。
 OPERATIONDENIED_ADDRESSINARREARS = 'OperationDenied.AddressInArrears'
 
@@ -743,6 +758,9 @@ UNSUPPORTEDOPERATION_BANDWIDTHPACKAGEIDNOTSUPPORTED = 'UnsupportedOperation.Band
 # 已绑定EIP。
 UNSUPPORTEDOPERATION_BINDEIP = 'UnsupportedOperation.BindEIP'
 
+# 添加 community 时，传播条件只支持 vpg 类型或 vpg 实例
+UNSUPPORTEDOPERATION_BROADCASTCONDITIONMUSTBEVPGTYPEORVPGINSTANCE = 'UnsupportedOperation.BroadcastConditionMustBeVpgTypeOrVpgInstance'
+
 # 指定VPC CIDR范围不支持私有网络和基础网络设备互通。
 UNSUPPORTEDOPERATION_CIDRUNSUPPORTEDCLASSICLINK = 'UnsupportedOperation.CIDRUnSupportedClassicLink'
 
@@ -761,12 +779,18 @@ UNSUPPORTEDOPERATION_CCNHASFLOWLOG = 'UnsupportedOperation.CcnHasFlowLog'
 # CCN实例所属账号未通过联通审批。
 UNSUPPORTEDOPERATION_CCNINSTANCEACCOUNTNOTAPPROVEDBYUNICOM = 'UnsupportedOperation.CcnInstanceAccountNotApprovedByUnicom'
 
+# 云联网开启ipv6不支持创建多路由表
+UNSUPPORTEDOPERATION_CCNIPV6NOTSUPPORTMULTIPLEROUTETABLE = 'UnsupportedOperation.CcnIpv6NotSupportMultipleRouteTable'
+
 # 实例未关联CCN。
 UNSUPPORTEDOPERATION_CCNNOTATTACHED = 'UnsupportedOperation.CcnNotAttached'
 
 # 当前云联网未开启路由传播策略。
 UNSUPPORTEDOPERATION_CCNNOTENABLEBROADCASTPOLICY = 'UnsupportedOperation.CcnNotEnableBroadcastPolicy'
 
+# 添加 community 时，vpg 需要开通传播 community 白名单
+UNSUPPORTEDOPERATION_CCNNOTENABLECOMMUNITY = 'UnsupportedOperation.CcnNotEnableCommunity'
+
 # 跨账号场景下不支持自驾云账号实例 关联普通账号云联网。
 UNSUPPORTEDOPERATION_CCNORDINARYACCOUNTREFUSEATTACH = 'UnsupportedOperation.CcnOrdinaryAccountRefuseAttach'
 
@@ -809,6 +833,9 @@ UNSUPPORTEDOPERATION_DELROUTEWITHSUBNET = 'UnsupportedOperation.DelRouteWithSubn
 # VPN通道状态为更新中/销毁中/创建中，不支持此操作。
 UNSUPPORTEDOPERATION_DELETEVPNCONNINVALIDSTATE = 'UnsupportedOperation.DeleteVpnConnInvalidState'
 
+# 发货失败。
+UNSUPPORTEDOPERATION_DELIVERYFAILED = 'UnsupportedOperation.DeliveryFailed'
+
 # 专线网关正在更新BGP Community属性。
 UNSUPPORTEDOPERATION_DIRECTCONNECTGATEWAYISUPDATINGCOMMUNITY = 'UnsupportedOperation.DirectConnectGatewayIsUpdatingCommunity'
 
@@ -914,6 +941,9 @@ UNSUPPORTEDOPERATION_ISNOTFINANCEACCOUNT = 'UnsupportedOperation.IsNotFinanceAcc
 # 该ISP不支持此操作。
 UNSUPPORTEDOPERATION_ISPNOTSUPPORTED = 'UnsupportedOperation.IspNotSupported'
 
+# 需要先解绑 IDC通道
+UNSUPPORTEDOPERATION_LDCXDISASSOCIATE = 'UnsupportedOperation.LDCXDisassociate'
+
 # 指定的CDC已存在本地网关。
 UNSUPPORTEDOPERATION_LOCALGATEWAYALREADYEXISTS = 'UnsupportedOperation.LocalGatewayAlreadyExists'
 
@@ -1040,6 +1070,9 @@ UNSUPPORTEDOPERATION_RECORDEXISTS = 'UnsupportedOperation.RecordExists'
 # 记录不存在。
 UNSUPPORTEDOPERATION_RECORDNOTEXISTS = 'UnsupportedOperation.RecordNotExists'
 
+# 此安全组存在嵌套安全组规则，不支持跨地域克隆。
+UNSUPPORTEDOPERATION_REMOTEREGIONSGHASREFERENCEDSG = 'UnsupportedOperation.RemoteRegionSgHasReferencedSg'
+
 # 资源处于不可用状态，禁止操作。
 UNSUPPORTEDOPERATION_RESOURCEISINVALIDSTATE = 'UnsupportedOperation.ResourceIsInvalidState'
 
